@@ -102,7 +102,7 @@ def interpret_drug_docking(
     Returns:
         Dictionary containing:
         - binding_energy_hartree: Ground state energy in Hartree
-        - binding_affinity_kcal_mol: ΔG in kcal/mol
+        - binding_affinity_kcal_mol: ΔG in kcal/mol (from REAL Vina if SMILES+PDB provided)
         - ki_molar: Inhibition constant in Molar
         - ki_nanomolar: Inhibition constant in nM
         - ic50_nanomolar: IC50 in nM
@@ -114,6 +114,92 @@ def interpret_drug_docking(
     ground_state_bitstring, ground_state_count = max(counts.items(), key=lambda x: x[1])
     total_shots = sum(counts.values())
 
+    # ========== REAL AUTODOCK VINA DOCKING (ALWAYS, NO APPROXIMATIONS) ==========
+    vina_affinity = None
+    vina_ki_nm = None
+    vina_ic50_nm = None
+    vina_num_poses = None
+
+    if smiles and pdb_id:
+        from bioql.docking.real_vina import (
+            dock_smiles_to_receptor,
+            prepare_receptor_pdbqt,
+            detect_binding_site,
+            HAVE_RDKIT,
+            VINA_BIN
+        )
+        from pathlib import Path
+        from bioql.molecular_utils import download_pdb
+
+        # Verificar que Vina está disponible
+        if not (HAVE_RDKIT and VINA_BIN):
+            missing = []
+            if not HAVE_RDKIT:
+                missing.append("RDKit (pip install rdkit)")
+            if not VINA_BIN:
+                missing.append("AutoDock Vina (brew install autodock-vina)")
+
+            raise RuntimeError(
+                f"❌ REAL docking requiere: {', '.join(missing)}\n"
+                f"BioQL 5.3.6+ NO usa aproximaciones cuánticas.\n"
+                f"Instala las dependencias para docking REAL."
+            )
+
+        # 1. 🔍 DOWNLOAD PDB
+        print(f"🔍 Downloading PDB {pdb_id} from RCSB...")
+        pdb_result = download_pdb(pdb_id)
+
+        if not pdb_result.get("success"):
+            raise RuntimeError(
+                f"❌ Error descargando PDB {pdb_id}: {pdb_result.get('error', 'Unknown error')}\n"
+                f"Verifica que el PDB ID existe en https://www.rcsb.org/"
+            )
+
+        pdb_path = Path(pdb_result["file_path"])
+        print(f"✅ PDB descargado: {pdb_path} ({pdb_result.get('size_bytes', 0)} bytes)")
+
+        # 2. ⚙️ PREPARE RECEPTOR (PDB → PDBQT)
+        print(f"⚙️ Preparing receptor (PDB → PDBQT)...")
+        output_dir = Path("/tmp/bioql_vina_docking")
+        output_dir.mkdir(parents=True, exist_ok=True)
+
+        receptor_pdbqt = output_dir / f"{pdb_id}_receptor.pdbqt"
+        prepare_receptor_pdbqt(pdb_path, receptor_pdbqt)
+        print(f"✅ Receptor preparado: {receptor_pdbqt}")
+
+        # 3. 🎯 DETECT BINDING SITE
+        print(f"🎯 Detecting binding site...")
+        center, box_size = detect_binding_site(pdb_path)
+        print(f"✅ Binding site: center={center}, box={box_size}")
+
+        # 4. 🚀 RUN REAL AUTODOCK VINA
+        print(f"🚀 Running AutoDock Vina docking...")
+        print(f"   Ligand SMILES: {smiles}")
+        print(f"   Receptor: {pdb_id}")
+        print(f"   Exhaustiveness: 8, Modes: 9")
+
+        vina_result = dock_smiles_to_receptor(
+            smiles=smiles,
+            receptor_pdbqt=receptor_pdbqt,
+            center=center,
+            box_size=box_size,
+            output_dir=output_dir,
+            exhaustiveness=8,
+            num_modes=9
+        )
+
+        # 5. ✅ EXTRACT REAL BINDING AFFINITY
+        vina_affinity = vina_result.best_affinity  # kcal/mol from REAL Vina
+        vina_ki_nm = vina_result.calculate_ki()  # nM
+        vina_ic50_nm = vina_result.calculate_ic50()  # nM
+        vina_num_poses = vina_result.num_poses
+
+        print(f"✅ REAL Docking Complete!")
+        print(f"   Binding Affinity: {vina_affinity:.2f} kcal/mol")
+        print(f"   Ki: {vina_ki_nm:.2f} nM")
+        print(f"   IC50: {vina_ic50_nm:.2f} nM")
+        print(f"   Poses: {vina_num_poses}")
+
     # Calculate VQE energy for ground state from QUANTUM measurements
     if hamiltonian is not None:
         energy_hartree = compute_vqe_energy(ground_state_bitstring, hamiltonian)
@@ -126,13 +212,20 @@ def interpret_drug_docking(
         # Typical drug binding energies: -0.01 to -0.05 Hartree
         energy_hartree = -0.05 + (num_ones / num_qubits) * 0.04
 
-    # Calculate thermodynamic properties from QUANTUM energy
-    binding_affinity_kcal = calculate_binding_affinity(energy_hartree)
-    ki_molar = calculate_ki(binding_affinity_kcal)
-    ic50_nanomolar = calculate_ic50(ki_molar)
+    # Calculate thermodynamic properties
+    # Use REAL Vina affinity if available, otherwise use quantum approximation
+    if vina_affinity is not None:
+        binding_affinity_kcal = vina_affinity  # REAL AutoDock Vina result
+        ki_molar = vina_ki_nm / 1e9  # Convert nM back to M
+        ic50_nanomolar = vina_ic50_nm
+    else:
+        # Fallback to quantum approximation
+        binding_affinity_kcal = calculate_binding_affinity(energy_hartree)
+        ki_molar = calculate_ki(binding_affinity_kcal)
+        ic50_nanomolar = calculate_ic50(ki_molar)
 
     # Analyze conformational diversity from QUANTUM state sampling
-    poses_explored = len(counts)
+    poses_explored = vina_num_poses if vina_num_poses else len(counts)
 
     # Calculate statistical confidence
     confidence = ground_state_count / total_shots
@@ -144,22 +237,23 @@ def interpret_drug_docking(
         smiles
     )
 
-    # Compile QUANTUM results
+    # Compile QUANTUM results (with REAL Vina data if available)
     results = {
         'application': 'drug_docking',
         'smiles': smiles,
         'pdb_id': pdb_id,
         'ground_state': ground_state_bitstring,
         'binding_energy_hartree': round(energy_hartree, 6),
-        'binding_affinity_kcal_mol': round(binding_affinity_kcal, 3),
+        'binding_affinity_kcal_mol': round(binding_affinity_kcal, 3),  # REAL Vina if available
         'ki_molar': f"{ki_molar:.2e}",
-        'ki_nanomolar': round(ki_molar * 1e9, 2),
-        'ic50_nanomolar': round(ic50_nanomolar, 2),
-        'poses_explored': poses_explored,
+        'ki_nanomolar': round(ki_molar * 1e9, 2),  # REAL Ki if Vina used
+        'ic50_nanomolar': round(ic50_nanomolar, 2),  # REAL IC50 if Vina used
+        'poses_explored': poses_explored,  # REAL poses if Vina used
         'total_shots': total_shots,
         'confidence': round(confidence, 4),
         'molecular_interactions': interactions,
-        'energy_distribution': calculate_energy_distribution(counts, hamiltonian)
+        'energy_distribution': calculate_energy_distribution(counts, hamiltonian),
+        'vina_used': vina_affinity is not None  # Flag indicating if REAL Vina was used
     }
 
     return results
