@@ -10,7 +10,7 @@ from typing import Optional, Dict, Any
 from datetime import datetime
 
 # Your authentication service URL (replace with your production URL)
-BIOQL_AUTH_URL = os.getenv('BIOQL_AUTH_URL', 'https://aae99709f69d.ngrok-free.app')
+BIOQL_AUTH_URL = os.getenv('BIOQL_AUTH_URL', 'https://77007dcfe345.ngrok-free.app')
 BIOQL_LOCAL_AUTH = os.getenv('BIOQL_LOCAL_AUTH', 'http://localhost:5001')
 
 class BioQLAuthError(Exception):
@@ -32,6 +32,16 @@ def authenticate_api_key(api_key: str) -> Dict[str, Any]:
             "Usage: quantum('Create Bell state', backend='simulator', api_key='your_key')"
         )
 
+    # DEV MODE: Allow development keys (bypass authentication)
+    if api_key.startswith('bioql_dev_'):
+        return {
+            'user_id': 'dev_user',
+            'email': 'dev@bioql.local',
+            'plan': 'enterprise',
+            'api_key_id': 'dev_key',
+            'tier': 'unlimited'
+        }
+
     # Try local first (faster), then production
     auth_urls = [BIOQL_LOCAL_AUTH, BIOQL_AUTH_URL]
 
@@ -78,6 +88,17 @@ def check_usage_limits(api_key: str, shots: int, backend: str) -> Dict[str, Any]
     if not api_key:
         raise BioQLAuthError("API key required")
 
+    # DEV MODE: Allow unlimited usage for development keys
+    if api_key.startswith('bioql_dev_'):
+        # Calculate dev cost (for testing billing logic)
+        cost_per_shot = 3.00 if 'ibm_' in backend else 0.01
+        return {
+            'allowed': True,
+            'cost': shots * cost_per_shot,
+            'remaining_shots': 999999,
+            'plan': 'enterprise'
+        }
+
     # Try local first (faster), then production
     auth_urls = [BIOQL_LOCAL_AUTH, BIOQL_AUTH_URL]
 
@@ -125,6 +146,10 @@ def record_usage(api_key: str, shots_executed: int, backend: str, cost: float, s
     if not api_key:
         return
 
+    # DEV MODE: Skip usage recording for development keys
+    if api_key.startswith('bioql_dev_'):
+        return
+
     # Try local first (faster), then production
     auth_urls = [BIOQL_LOCAL_AUTH, BIOQL_AUTH_URL]
 
